==> rn-hidoop-ui-lib-0.1.2.tgz: package/src/Components/Molecules/Input/PinInput.js <==
import { debounce } from 'lodash';
import React, { useCallback, useEffect, useRef, useState } from 'react';
import {
  Keyboard,
  StyleSheet,
  TextInput,
  TouchableWithoutFeedback,
  View,
} from 'react-native';
import { colors, width } from '../../../constant/theme';
import Text from '../../Atoms/Text';

const PinInput = (props) => {
  const {
    pinCount,
    onSubmit,
    submitted,
    autofilledInput,
    styleProps,
    borderBottomColorInactive,
    borderBottomColorActive,
    type,
    showInvalid,
    setShowInvalid,
    returnType,
    clearInput,
    setClearInput,
    onPinFilled = () => {},
    route,
  } = props;

  const fields = useRef(null);

  const [input, setInput] = useState('');
  const [renderedInput, setRenderedInput] = useState('');

  const changeTextToAskterisk = () => {
    setRenderedInput((renderedInput) => '*'.repeat(renderedInput.length));
  };

  const debounceHandler = useCallback(debounce(changeTextToAskterisk, 500), []);

  useEffect(() => {
    setTimeout(() => {
      focusField();
    }, 350);
  }, []);

  useEffect(() => {
    if (input.length === pinCount) {
      onPinFilled({ isFilled: true, pinValue: input });
    } else if (input.length < pinCount) {
      onPinFilled({ isFilled: false });
    }
  }, [input, pinCount]);

  useEffect(() => {
    if (autofilledInput?.length === pinCount) {
      setInput(autofilledInput);
      Keyboard.dismiss();
    }

    if (type === 'pin') {
      if (submitted) {
        console.log('submitted and filled', input);
        Keyboard.dismiss();
      }
    }
  }, [submitted, autofilledInput, type]);

  useEffect(() => {
    if (showInvalid) {
      console.log('showInvalid');
      setInput('');
      setRenderedInput('');
    }

    if (clearInput) {
      console.log('clear');
      setInput('');
      setRenderedInput('');
    }
  }, [showInvalid, clearInput]);

  const handleChangeText = (text) => {
    showInvalid && setShowInvalid(false);
    clearInput && setClearInput(false);
    if (text.length <= pinCount) {
      setInput(text);
      if (type === 'pin') {
        if (text.length < renderedInput.length) {
          setRenderedInput((renderedInput) =>
            renderedInput.substring(0, text.length)
          );
        } else {
          setRenderedInput('*'.repeat(text.length - 1) + text[text.length - 1]);
          debounceHandler();
        }
      }
    }

    if (text.length === pinCount && type === 'pin') {
      Keyboard.dismiss();
      console.log('text', text);
      // onSubmit(text);
    }

    // console.log("text.length", text.length, pinCount, type);
    if (text.length === pinCount && type === 'otp') {
      Keyboard.dismiss();
    }
  };

  const focusField = () => {
    Keyboard.dismiss();
    setTimeout(() => {
      fields.current ? fields.current.focus() : null;
    }, 85);
  };

  const blurAll = () => {
    fields.current.blur();
  };

  const renderOneField = (_, index) => {
    if (renderedInput[index + 1] !== undefined) {
      return <View key={index} style={styles.dot} />;
    } else {
      return (
        <View
          key={index + 'view'}
          style={
            styleProps
              ? [
                  styleProps,
                  {
                    borderBottomColor:
                      renderedInput[index] === undefined
                        ? borderBottomColorInactive
                        : borderBottomColorActive,
                  },
                ]
              : [
                  styles.defaultTextFieldStyle,
                  styles.inputContainerOtp,
                  {
                    borderBottomColor:
                      input[index] === undefined
                        ? borderBottomColorInactive
                        : borderBottomColorActive,
                  },
                ]
          }
        >
          <Text
            key={index}
            text={type === 'pin' ? renderedInput[index] : input[index]}
            color={type === 'pin' ? 'white' : colors.grey.black}
            size="extraLarge"
            textStyle={{ textAlign: 'center' }}
            variant="semibold"
          />
        </View>
      );
    }
  };

  const renderTextFields = () => {
    const pin = new Array(pinCount).fill(0);
    return pin.map(renderOneField);
  };

  return (
    <View style={{ marginTop: width * 0.2 }}>
      <TextInput
        ref={fields}
        style={styles.hiddenTextInput}
        onChangeText={handleChangeText}
        keyboardType="phone-pad"
        value={input}
        textContentType="oneTimeCode"
        underlineColorAndroid="transparent"
      />
      <TouchableWithoutFeedback onPress={focusField}>
        <View style={styles.inputWrapper}>
          <View style={[styles.container, type === 'otp' && { width: '80%' }]}>
            {renderTextFields()}
          </View>
        </View>
      </TouchableWithoutFeedback>
    </View>
  );
};

export const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    width: '100%',
    justifyContent: 'space-evenly',
    alignItems: 'center',
  },
  defaultTextFieldStyle: {
    width: 37,
    borderColor: 'white',
    borderWidth: 0,
    borderRadius: 5,
    textAlign: 'center',
    paddingTop: 0,
  },
  inputContainerOtp: {
    height: 46,
    justifyContent: 'center',
    alignItems: 'center',
    borderRadius: 0,
    borderBottomWidth: 2,
  },
  hiddenTextInput: { width: 0, height: 0, position: 'absolute' },
  inputWrapper: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
  dot: {
    width: 20,
    height: 20,
    borderRadius: 15,
    backgroundColor: 'white',
  },
});

export default PinInput;

==> rn-hidoop-ui-lib-0.1.13.tgz: package/src/Components/Molecules/Input/PinInput.js <==
import { debounce } from 'lodash';
import React, { useCallback, useEffect, useRef, useState } from 'react';
import {
  Keyboard,
  StyleSheet,
  TextInput,
  TouchableWithoutFeedback,
  View,
} from 'react-native';
import { colors, width } from '../../../constant/theme';
import Text from '../../Atoms/Text';

const PinInput = (props) => {
  const {
    pinCount,
    onSubmit,
    submitted,
    autofilledInput,
    styleProps,
    borderBottomColorInactive,
    borderBottomColorActive,
    type,
    showInvalid,
    setShowInvalid,
    returnType,
    clearInput,
    setClearInput,
    onPinFilled = () => {},
    route,
  } = props;

  const fields = useRef(null);

  const [input, setInput] = useState('');
  const [renderedInput, setRenderedInput] = useState('');

  const changeTextToAskterisk = () => {
    setRenderedInput((renderedInput) => '*'.repeat(renderedInput.length));
  };

  const debounceHandler = useCallback(debounce(changeTextToAskterisk, 500), []);

  useEffect(() => {
    setTimeout(() => {
      focusField();
    }, 350);
  }, []);

  useEffect(() => {
    if (input.length === pinCount) {
      onPinFilled({ isFilled: true, pinValue: input });
    } else if (input.length < pinCount) {
      onPinFilled({ isFilled: false });
    }
  }, [input, pinCount]);

  useEffect(() => {
    if (autofilledInput?.length === pinCount) {
      setInput(autofilledInput);
      Keyboard.dismiss();
    }

    if (type === 'pin') {
      if (submitted) {
        console.log('submitted and filled', input);
        Keyboard.dismiss();
      }
    }
  }, [submitted, autofilledInput, type]);

  useEffect(() => {
    if (showInvalid) {
      console.log('showInvalid');
      setInput('');
      setRenderedInput('');
    }

    if (clearInput) {
      console.log('clear');
      setInput('');
      setRenderedInput('');
    }
  }, [showInvalid, clearInput]);

  const handleChangeText = (text) => {
    showInvalid && setShowInvalid(false);
    clearInput && setClearInput(false);
    if (text.length <= pinCount) {
      setInput(text);
      if (type === 'pin') {
        console.log('text', text);
        if (text.length < renderedInput.length) {
          setRenderedInput((renderedInput) => {
            console.log('renderedInput', renderedInput);
            return renderedInput.substring(0, text.length);
          });
        } else {
          setRenderedInput('*'.repeat(text.length - 1) + text[text.length - 1]);
          debounceHandler();
        }
      }
    }

    if (text.length === pinCount && type === 'pin') {
      Keyboard.dismiss();
      console.log('text', text);
      // onSubmit(text);
    }

    // console.log("text.length", text.length, pinCount, type);
    if (text.length === pinCount && type === 'otp') {
      Keyboard.dismiss();
    }
  };

  const focusField = () => {
    Keyboard.dismiss();
    setTimeout(() => {
      fields.current ? fields.current.focus() : null;
    }, 85);
  };

  const blurAll = () => {
    fields.current.blur();
  };

  const renderOneField = (i, index) => {
    if (type === 'pin') {
      if (renderedInput[index + 1] !== undefined) {
        return <View key={index} style={styles.dot} />;
      } else {
        if (renderedInput[index] === undefined) {
          return <View key={index} style={styles.dot} />;
        }
        return (
          <View
            key={index + 'view'}
            style={[
              styles.defaultTextFieldStyle,
              styles.inputContainerPin,
              {
                borderBottomColor:
                  input[index] === undefined
                    ? borderBottomColorInactive
                    : borderBottomColorActive,
              },
            ]}
          >
            <Text
              key={index}
              text={input[index]}
              color={colors.grey.white}
              size="extraLarge"
              textStyle={{ textAlign: 'center' }}
              variant="semibold"
            />
          </View>
        );
      }
    } else {
      return (
        <View
          key={index + 'view'}
          style={[
            styles.defaultTextFieldStyle,
            styles.inputContainerOtp,
            {
              borderBottomColor:
                input[index] === undefined
                  ? borderBottomColorInactive
                  : borderBottomColorActive,
            },
          ]}
        >
          <Text
            key={index}
            text={input[index]}
            color={colors.grey.white}
            size="extraLarge"
            textStyle={{ textAlign: 'center' }}
            variant="semibold"
          />
        </View>
      );
    }
  };

  const renderTextFields = () => {
    const pin = new Array(pinCount).fill(0);
    return pin.map((i, index) => renderOneField(i, index));
  };

  return (
    <View style={{ marginTop: width * 0.2 }}>
      <TextInput
        ref={fields}
        style={styles.hiddenTextInput}
        onChangeText={handleChangeText}
        keyboardType="phone-pad"
        value={input}
        textContentType="oneTimeCode"
        underlineColorAndroid="transparent"
      />
      <TouchableWithoutFeedback onPress={focusField}>
        <View style={styles.inputWrapper}>
          <View style={[styles.container]}>{renderTextFields()}</View>
        </View>
      </TouchableWithoutFeedback>
    </View>
  );
};

export const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    width: '100%',
    justifyContent: 'space-evenly',
    alignItems: 'center',
  },
  defaultTextFieldStyle: {
    width: 37,
    borderColor: 'white',
    borderWidth: 0,
    borderRadius: 5,
    textAlign: 'center',
    paddingTop: 0,
  },
  inputContainerPin: {
    height: 46,
    justifyContent: 'center',
    alignItems: 'center',
    borderRadius: 0,
  },
  inputContainerOtp: {
    height: 46,
    justifyContent: 'center',
    alignItems: 'center',
    borderRadius: 0,
    borderBottomWidth: 2,
  },
  hiddenTextInput: { width: 0, height: 0, position: 'absolute' },
  inputWrapper: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
  dot: {
    width: 20,
    height: 20,
    marginHorizontal: 10,
    borderRadius: 15,
    backgroundColor: 'white',
  },
});

export default PinInput;
